;(function(){
  var map = {
  "commitId": "9683fc039855b27aa0a503201915ba5ab6bda492",
  "branchName": "release-client-5.17.x",
  "buildTime": "2023-12-21 07:52:04 GMT",
  "buildVersion": "5.1.977",
  "css": [
    "@zoom/client-calendar/static/css/chunk-vendors.974eca6e.css",
    "@zoom/client-calendar/static/css/app.7c5cc38c.css"
  ],
  "js": [
    "@zoom/client-calendar/static/js/chunk-vendors.9eb0a6bb.js",
    "@zoom/client-calendar/static/js/app.0e7eb3ae.js"
  ],
  "key": "@zoom/client-calendar"
};
  var prefix = 'https://dev-integration.zoomdev.us/fe-static/';
  map.css && map.css.forEach(function (cssItem) {
    var linkTag = document.createElement('link');
    var cssURL = prefix +  cssItem ;
    linkTag.href = cssURL;
    linkTag.setAttribute('rel','stylesheet');
    document.head.appendChild(linkTag);
  });
  map.js && map.js.forEach(function (jsItem) {
    var scriptTag = document.createElement("script");
    var jsURL = prefix +  jsItem;
    scriptTag.setAttribute("src", jsURL);
    document.body.appendChild(scriptTag);
  });
  window.domainFromServer= "https://dev-integration.zoomdev.us/fe-static/";
})();
